﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Forms;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.Xml;
using System.Xml.Serialization;
using WpfDemo.XMLEntities;

namespace WpfDemo
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        // 创建空实例
        private MyClass _myClassInfo = new MyClass();

        public MainWindow()
        {
            InitializeComponent();

            //将空实例设置为View的DataContext
            base.DataContext = _myClassInfo;
        }

        private void btnNewTeacher_Click(object sender, RoutedEventArgs e)
        {
            try
            {
                if (_myClassInfo.Teachers == null)
                {
                    _myClassInfo.Teachers = new System.Collections.ObjectModel.ObservableCollection<MyTeacher>();
                }

                _myClassInfo.Teachers.Add(new MyTeacher());

                tabTeachers.SelectedIndex = _myClassInfo.Teachers.Count - 1;
            }
            catch (Exception)
            {
            }
        }

        private void btnDeleteTeacher_Click(object sender, RoutedEventArgs e)
        {
            try
            {
                var teacher = _myClassInfo.Teachers[tabTeachers.SelectedIndex];
                if (System.Windows.MessageBox.Show("Are you sure to remove current teacher '" + teacher.Name + "'?", "Delete teacher", MessageBoxButton.YesNo) == MessageBoxResult.Yes)
                {
                    _myClassInfo.Teachers.RemoveAt(tabTeachers.SelectedIndex);
                }
            }
            catch (Exception)
            {
            }
        }

        private void btnNewStudent_Click(object sender, RoutedEventArgs e)
        {
            try
            {
                if (_myClassInfo.Students == null)
                {
                    _myClassInfo.Students = new System.Collections.ObjectModel.ObservableCollection<MyStudent>();
                }

                _myClassInfo.Students.Add(new MyStudent());

                tabStudents.SelectedIndex = _myClassInfo.Students.Count - 1;
            }
            catch (Exception)
            {
            }
        }

        private void btnDeleteStudent_Click(object sender, RoutedEventArgs e)
        {
            try
            {
                var student = _myClassInfo.Students[tabStudents.SelectedIndex];
                if (System.Windows.MessageBox.Show("Are you sure to remove current student '" + student.Name + "'?", "Delete student", MessageBoxButton.YesNo) == MessageBoxResult.Yes)
                {
                    _myClassInfo.Students.RemoveAt(tabStudents.SelectedIndex);
                }
            }
            catch (Exception)
            {
            }
        }

        private void btnBrowsePath_Click(object sender, RoutedEventArgs e)
        {
            try
            {
                OpenFileDialog dialog = new OpenFileDialog();
                dialog.DefaultExt = "xml";
                dialog.Filter = "XML documents (*.xml)|*.xml";
                dialog.FileName = "my-class-test";

                var dr = dialog.ShowDialog();
                if (dr == System.Windows.Forms.DialogResult.OK)
                {
                    txtFilePath.Text = dialog.FileName;
                }
            }
            catch (Exception)
            {
            }
        }

        private void btnSave_Click(object sender, RoutedEventArgs e)
        {
            try
            {
                string xmlFilePath = txtFilePath.Text.Trim();
                if (!string.IsNullOrEmpty(xmlFilePath))
                {
                    XmlWriterSettings settings = new XmlWriterSettings()
                    {
                        Encoding = Encoding.UTF8,
                        OmitXmlDeclaration = true,
                        NewLineOnAttributes = true,
                        Indent = true,
                        ConformanceLevel = ConformanceLevel.Document
                    };

                    XmlSerializerNamespaces ns = new XmlSerializerNamespaces();
                    ns.Add("", "");

                    using (FileStream fs = new FileStream(xmlFilePath, FileMode.Create))
                    using (var writer = XmlWriter.Create(fs, settings))
                    {
                        writer.WriteRaw("<?xml version=\"1.0\" encoding=\"UTF-8\"?>\r\n");

                        XmlSerializer xmlSerializer = new XmlSerializer(typeof(MyClass));
                        xmlSerializer.Serialize(writer, _myClassInfo, ns);
                        System.Windows.Forms.MessageBox.Show("Success!");
                    }
                }
                else
                {
                    System.Windows.Forms.MessageBox.Show("Choose a file path to save!");
                }
            }
            catch (Exception)
            {
            }
        }

        private void btnLoad_Click(object sender, RoutedEventArgs e)
        {
            try
            {
                OpenFileDialog dialog = new OpenFileDialog();
                dialog.DefaultExt = "xml";
                dialog.Filter = "XML documents (*.xml)|*.xml";
                dialog.FileName = "my-class-test";

                var dr = dialog.ShowDialog();
                if (dr == System.Windows.Forms.DialogResult.OK)
                {
                    txtFilePath.Text = dialog.FileName;

                    using (FileStream fs = File.OpenRead(dialog.FileName))
                    {
                        XmlSerializer xmlSerializer = new XmlSerializer(typeof(MyClass));
                        _myClassInfo = xmlSerializer.Deserialize(fs) as MyClass;
                        base.DataContext = _myClassInfo;

                        this.tabStudents.SelectedIndex = 0;
                        this.tabTeachers.SelectedIndex = 0;
                    }
                }
            }
            catch (Exception)
            {
            }
        }
    }
}
